/* CSuperViewDivider.cp - this is like CViewDivider
	except that visually, it has no breaks at the top
	and bottom, and when you resize, it
	calls a method in its superview,
	(which resizes this one and all its siblings)

	i.e.:
	This is a divider that, during a mouse drag divides the view of
		its parent, not just itself, and at the end of its drag sends the parent
		a MoveDividerBy message (so a group of dividers can move in unison.)


	one use of this class:
	Allow a single divider to control all elements of
	a columview.
 */
#include "CSuperViewDivider.h"
#include "CViewColumn.h"

CSuperViewDivider::CSuperViewDivider(LStream *inStream) : CViewDivider(inStream){
}

/* GetDragLimitSlop - parameters for DragGrayRgn in ClickSelf:
	get them from our superview.
 */
void CSuperViewDivider::GetDragLimitSlop(Rect& outR, Rect& outLimitR, Rect& outSlopR){
	GetDividerRect(outR);
	mSuperView->FocusDraw();
	mSuperView->PortToLocalPoint(topLeft(outR));
	mSuperView->PortToLocalPoint(botRight(outR));
	mSuperView->CalcLocalFrameRect(outLimitR);
	if(mIsHorizontal){
		outR.top = outLimitR.top;
		outR.bottom = outLimitR.bottom;
	}else{
		outR.left = outLimitR.left;
		outR.right = outLimitR.right;
	}
	outSlopR = outLimitR;
	::InsetRect(&outSlopR, -100, -100);
}

/* DrawSelf - 
 */
void CSuperViewDivider::DrawSelf(){
	Rect		r;
	RGBColor	saveFore;
	static RGBColor	darkRGB = { 0xBBBB, 0xBBBB, 0xBBBB };
	static RGBColor lightRGB = { 0xFFFF, 0xFFFF, 0xFFFF };
	static RGBColor lidRGB = { 0xDDDD, 0xDDDD, 0xDDDD };

	FocusDraw();

	GetDividerRect(r);
	PortToLocalPoint(topLeft(r));
	PortToLocalPoint(botRight(r));

#if 1
	GetForeColor(&saveFore);
	RGBForeColor(&lightRGB);
	if(mIsHorizontal){
		MoveTo(r.left, r.bottom-1);
		LineTo(r.left, r.top);
		RGBForeColor(&darkRGB);
		MoveTo(r.right-1, r.top);
		LineTo(r.right-1, r.bottom-1);
		RGBForeColor(&lidRGB);
		r.left++;
		r.right--;
		PaintRect(&r);
	}else{
		MoveTo(r.left, r.top);
		LineTo(r.right-1, r.top);
		RGBForeColor(&darkRGB);
		MoveTo(r.left, r.bottom-1);
		LineTo(r.right-1, r.bottom-1);
		RGBForeColor(&lidRGB);
		r.top++;
		r.bottom--;
		PaintRect(&r);
	}
	RGBForeColor(&saveFore);
#else
	PaintRect(&r);
#endif
}

/* MoveDividerBy - tell our super to tell us and our siblings to actually move it.
 */
void CSuperViewDivider::MoveDividerBy(SInt16	dx, SInt16 dy, Boolean inRefresh){
	CViewDividerOwner	*super;

	if(nil != (super = dynamic_cast<CViewDividerOwner*>(mSuperView))){
		super->MoveDividerBy(dx, dy, inRefresh);
	}
}


/* ####################################################################################
 */

/* MoveDividerBy - tell all our children to actually move their
	divider.
	works in conjunction with CSuperViewDivider
 */
void CViewDividerOwner::MoveDividerBy(SInt16 dx, SInt16 dy, Boolean inRefresh){
	LArrayIterator	iter(GetSubPanes(), LArrayIterator::from_Start);
	LPane*			pIth;
	CViewDivider*	vDiv;

	while(iter.Next(&pIth)){
		if(nil != (vDiv = dynamic_cast<CViewDivider*>(pIth))){
			vDiv->MoveDividerBySelf(dx, dy, inRefresh);
		}
	}
}

