/* CViewColumn.h - This View is a columnar table of sub-views.

	Version 1.4 Jan 2002
	1.1 rev'ed: fix incompatibilities introduced in Pro 2
	1.2 bug fixes in CViewColumn.cp when adding panes into scrolled views.
	1.3 rev'ed: fix incompatibilities introduced in Pro 5.3
	1.4 rev'ed: fix incompatibilities introduced in Pro 7.1
	Copyright 1997-2002 by David Phillip Oster <mail-to:oster@ieee.org>

	The semi-legal stuff:
 
	You may use this any way you see fit, but:
		by your use of this you this you agree to hold David Oster harmless of any liability
			that may result from your use of this.
	You may not remove David Oster's name and contact info from the source code, although you
		may add your own.
	You agree to e-mail David Oster about bugs and problems with this source code.

	insert subViews with CreateSubPane.
	1s-based array access them using GetSubPane.

	as we insert and remove subPanes, the following subPanes adjust their
		positions.

	Note: if a subPane changes height after it is installed, this code
		will _not_ detect that and slide the following subPanes
		up or down appropriately. You can get that effect by removing it and re-inserting it.

	Note: this uses a vertical layout policy
 */
#pragma once

class CViewColumn : public LView {
public:
	enum { class_ID = 'sVsW' };

	CViewColumn(LStream *inStream);

	virtual LPane*	CreateSubPane(SInt32 index, ResIDT inPPobID, Boolean inRefresh);

	virtual LPane*	GetSubPane(SInt32 index);

	virtual const LPane*	GetConstSubPane(SInt32 index)const;

	virtual SInt32	GetPaneCount()const;

	virtual SInt32	GetValue() const;	// integer index of top visible subView

	virtual void	SetValue(SInt32 inValue);	// scroll to make inValue the top visible subView

	virtual void	RemoveSubPane(LPane	*inSub);

	static void		GetSuperViewColumn(LPane* inMe, CViewColumn* &outSuper, LPane* &outSub);

	static void		ScrollSubPaneIntoFrame(LPane *inSub);	// like LTableView::ScrollCellIntoFrame
};
